(function (Drupal) {
  Drupal.behaviors.sneakPeek = {
    attach: function (context, settings) {
      if (!document.getElementById('sneak-peak')) {
        const sneakPeakContainer = document.createElement('div');
        sneakPeakContainer.id = 'sneak-peak';
        sneakPeakContainer.classList.add('sneak-peak-modal');
        sneakPeakContainer.setAttribute('role', 'dialog');
        sneakPeakContainer.setAttribute('aria-hidden', 'true');
        sneakPeakContainer.setAttribute('aria-labelledby', 'sneak-peak-title');

        const closeButton = document.createElement('div');
        closeButton.classList.add('close');
        closeButton.textContent = 'X';
        closeButton.setAttribute('role', 'button');
        closeButton.setAttribute('aria-label', 'Close');

        const contentContainer = document.createElement('div');
        contentContainer.id = 'sneak-peak-content';
        contentContainer.classList.add('container', 'content-wrapper');

        sneakPeakContainer.appendChild(closeButton);
        sneakPeakContainer.appendChild(contentContainer);

        document.body.appendChild(sneakPeakContainer);

        closeButton.addEventListener('click', function () {
          contentContainer.innerHTML = '';
          sneakPeakContainer.classList.remove('active', 'processing');
          sneakPeakContainer.setAttribute('aria-hidden', 'true');

          if (sneakPeakContainer.dataset.lastFocused) {
            document.querySelector(sneakPeakContainer.dataset.lastFocused).focus();
          }
        });
      }

      const links = context.querySelectorAll('.sneak-peak-link');

      links.forEach(link => {
        if (!link.classList.contains('sneakPeak')) {
          link.classList.add('sneakPeak');

          link.addEventListener('click', function (e) {
            e.preventDefault();
            const sneakPeakContainer = document.getElementById('sneak-peak');
            const contentContainer = document.getElementById('sneak-peak-content');

            sneakPeakContainer.dataset.lastFocused = `a[href="${link.getAttribute('href')}"]`;

            sneakPeakContainer.classList.remove('active');
            sneakPeakContainer.classList.add('processing');
            sneakPeakContainer.setAttribute('aria-hidden', 'false');

            sneakPeakContainer.querySelector('.close').focus();

            const url = link.getAttribute('href');
            fetch(url)
              .then(response => response.json())
              .then(data => {
                contentContainer.innerHTML = data.content || '<p>Failed to load content.</p>';
              })
              .catch(() => {
                contentContainer.innerHTML = '<p>Failed to load content.</p>';
              })
              .finally(() => {
                sneakPeakContainer.classList.add('active');
                sneakPeakContainer.classList.remove('processing');
              });
          });
        }
      });
    },
  };
})(Drupal);
