<?php

namespace Drupal\sneak_peak\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\JsonResponse;
use Drupal\node\Entity\Node;
use Drupal\Core\Render\RendererInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

class SneakPeakController extends ControllerBase {

  /**
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * Constructs a SneakPeakController object.
   *
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   The renderer service.
   */
  public function __construct(RendererInterface $renderer) {
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('renderer')
    );
  }

  /**
   * Loads Content for Sneak Peak via AJAX.
   *
   * @param int $node
   *   The ID of node.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   JSON with returned message. Can be the node or an error message.
   */
  public function ajaxLoad($node) {
    if (!\Drupal::currentUser()->hasPermission('use sneak peak')) {
      return new JsonResponse(['error' => 'Access denied'], 403);
    }

    $config = $this->config('sneak_peak.settings');
    $enabled_content_types = $config->get('enabled_content_types');
    $view_mode = $config->get('view_mode') ?? 'teaser';

    $node = Node::load($node);

    if ($node && $node->access('view') && in_array($node->bundle(), $enabled_content_types)) {
      $view_builder = \Drupal::entityTypeManager()->getViewBuilder('node');
      $build = $view_builder->view($node, $view_mode);

      $output = $this->renderer->render($build);
      return new JsonResponse([
        'content' => $output,
      ]);
    }

    return new JsonResponse(['error' => 'Access denied or content not found'], 403);
  }
}
