<?php

namespace Drupal\sneak_peak\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\node\Entity\NodeType;

class SneakPeakSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['sneak_peak.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'sneak_peak_settings_form';
  }

  /**
   * Builds the form.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('sneak_peak.settings');

    $content_types = NodeType::loadMultiple();
    $content_type_options = [];
    foreach ($content_types as $type) {
      $content_type_options[$type->id()] = $type->label();
    }

    $view_modes = \Drupal::service('entity_display.repository')->getViewModes('node');
    $view_mode_options = [];
    foreach ($view_modes as $key => $view_mode) {
      $view_mode_options[$key] = $view_mode['label'];
    }

    $form['content_settings'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Content Settings'),
    ];

    $form['content_settings']['enabled_content_types'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Enabled Content Types'),
      '#description' => $this->t('Select the content types for which Sneak peak is enabled.'),
      '#options' => $content_type_options,
      '#default_value' => $config->get('enabled_content_types'),
    ];

    $form['content_settings']['view_mode'] = [
      '#type' => 'select',
      '#title' => $this->t('View Mode'),
      '#description' => $this->t('Select the view mode to display the content in the sneak peak.'),
      '#options' => $view_mode_options,
      '#default_value' => $config->get('view_mode'),
    ];

    $form['content_settings']['sneak_peak_title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Link Title'),
      '#description' => $this->t('The text to display on the link.'),
      '#default_value' => $config->get('sneak_peak_title'),
    ];

    $form['animation_settings'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Animation Settings'),
    ];

    $form['animation_settings']['animation_style'] = [
      '#type' => 'select',
      '#title' => $this->t('Animation Style'),
      '#description' => $this->t('Choose the animation style for the sneak peek.'),
      '#options' => [
        'sneak_peak/modal' => $this->t('Modal'),
        'sneak_peak/slide_in' => $this->t('Slide In'),
      ],
      '#default_value' => $config->get('animation_style') ?? 'sneak_peak/slide_in',
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('sneak_peak.settings')
      ->set('enabled_content_types', array_filter($form_state->getValue('enabled_content_types')))
      ->set('view_mode', $form_state->getValue('view_mode'))
      ->set('sneak_peak_title', $form_state->getValue('sneak_peak_title'))
      ->set('animation_style', $form_state->getValue('animation_style'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
